setGain method
Forces a master volume modification at the native signal stage.
Implementation
void setGain(double gain) => _setGainNative(gain);
Forces a master volume modification at the native signal stage.
void setGain(double gain) => _setGainNative(gain);