GetTimeDart typedef
GetTimeDart =
double Function()
Defines the Dart layout for the media clock time.
Implementation
typedef GetTimeDart = double Function();
Defines the Dart layout for the media clock time.
typedef GetTimeDart = double Function();