GetTimeNative typedef
GetTimeNative =
Double Function()
Defines the native C layout for the media clock time.
Implementation
typedef GetTimeNative = ffi.Double Function();
Defines the native C layout for the media clock time.
typedef GetTimeNative = ffi.Double Function();