LoadSubtitlesDart typedef
LoadSubtitlesDart =
void Function(Pointer<Utf8> data)
Defines the Dart layout for loading raw subtitle data.
Implementation
typedef LoadSubtitlesDart = void Function(ffi.Pointer<Utf8> data);
Defines the Dart layout for loading raw subtitle data.
typedef LoadSubtitlesDart = void Function(ffi.Pointer<Utf8> data);