StopEngineNative typedef
StopEngineNative =
Void Function()
Defines the native C layout for halting the DSP thread.
Implementation
typedef StopEngineNative = ffi.Void Function();
Defines the native C layout for halting the DSP thread.
typedef StopEngineNative = ffi.Void Function();